@@ -16,9 +16,11 @@ from channels.db import database_sync_to_async as dbaccess
 from django.db.models import Q
 from django.core.exceptions import ObjectDoesNotExist
 from multiprocessing import Pool
-from web_dj_collector.manage import setup
 
-setup()
+import django
+import os
+
+django.setup()
 
 from apps.station.models import InstallationEndPoint
 from apps.status_unidad.models import LogUnidadGNSS
